<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_DE" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Nach links bewegen</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Nach rechts bewegen</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Aus dem Schnellstarter löschen</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>Drop Error</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Datei/Pfad &apos;%1&apos; kann im moment nicht in den Schnellstarter integriert werden</translation>
    </message>
</context>
</TS>